@@ -12,8 +12,7 @@ public class test {
     }
   }
 
-  public static void main(String[] argv)
-  {
+  public static void main(String[] argv) {
      System.out.println (MeCab.VERSION);
      String arg = "";
      for (int i = 0; i < argv.length; i++) {
@@ -21,7 +20,7 @@ public class test {
 	arg += argv[i];
      }
 
-     Tagger tagger = new Tagger (arg);
+     Tagger tagger = new Tagger();
      System.out.println (tagger.parse ("ϺϺˤܤϤ."));
 
      for (Node node = tagger.parseToNode ("ϺϺˤܤϤ.");
